@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // KDE
 
 // Qt
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 #include <QGuiApplication>
 #include <QCursor>
 #include <QGraphicsSceneMouseEvent>
