@@ -97,7 +97,8 @@ int main(int argc, char** argv)
     // List dir
     QDir dir(imageDirName);
     KFileItemList list;
-    Q_FOREACH(const QString &name, dir.entryList()) {
+    const auto entryList = dir.entryList();
+    for (const QString &name : entryList) {
         QUrl url = QUrl::fromLocalFile(dir.absoluteFilePath(name));
         KFileItem item(url);
         list << item;
@@ -105,7 +106,7 @@ int main(int argc, char** argv)
     qWarning() << "Generating thumbnails for" << list.count() << "files";
 
     // Start the job
-    QTime chrono;
+    QElapsedTimer chrono;
     ThumbnailProvider job;
     job.setThumbnailGroup(group);
     job.appendItems(list);
